@@ -7,7 +7,7 @@ import warnings
 warnings.filterwarnings('ignore')
 
 
-from ml_processor.outliers import remove_outliers
+from .outliers import remove_outliers
 
 def eda_data_quality (data):
     
